summaryrefslogtreecommitdiff
path: root/src/mongo/db/ops/parsed_update.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/ops/parsed_update.h')
-rw-r--r--src/mongo/db/ops/parsed_update.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/src/mongo/db/ops/parsed_update.h b/src/mongo/db/ops/parsed_update.h
index da983db9f1f..3764b5f85d2 100644
--- a/src/mongo/db/ops/parsed_update.h
+++ b/src/mongo/db/ops/parsed_update.h
@@ -71,10 +71,12 @@ public:
/**
* Constructs a parsed update.
*
* The object pointed to by "request" must stay in scope for the life of the constructed
* ParsedUpdate.
*/
- ParsedUpdate(OperationContext* opCtx, const UpdateRequest* request);
+ ParsedUpdate(OperationContext* opCtx,
+ const UpdateRequest* request,
+ const ExtensionsCallback& extensionsCallback);
/**
* Parses the update request to a canonical query and an update driver. On success, the
@@ -167,6 +169,9 @@ private:
// Parsed query object, or NULL if the query proves to be an id hack query.
std::unique_ptr<CanonicalQuery> _canonicalQuery;
+
+ // Reference to an extensions callback used when parsing to a canonical query.
+ const ExtensionsCallback& _extensionsCallback;
};
} // namespace mongo
@@ -71,10 +71,12 @@ public:
* Constructs a parsed update.
*
- * The object pointed to by "request" must stay in scope for the life of the constructed
- * ParsedUpdate.
+ * The objects pointed to by "request" and "extensionsCallback" must stay in scope for the life
+ * of the constructed ParsedUpdate.
*/